#! /usr/bin/env bash
# This file contains the complete sequence of commands
# CodeSourcery used to build this version of Sourcery G++.
# 
# For each free or open-source component of Sourcery G++, the
# source code provided includes all of the configuration
# scripts and makefiles for that component, including any and
# all modifications made by CodeSourcery.  From this list of
# commands, you can see every configuration option used by
# CodeSourcery during the build process.
# 
# This file is provided as a guideline for users who wish to
# modify and rebuild a free or open-source component of
# Sourcery G++ from source. For a number of reasons, though,
# you may not be able to successfully run this script directly
# on your system. Certain aspects of the CodeSourcery build
# environment (such as directory names) are included in these
# commands. CodeSourcery uses Canadian cross compilers so you
# may need to modify various configuration options and paths
# if you are building natively. This sequence of commands
# includes those used to build proprietary components of
# Sourcery G++ for which source code is not provided.
# 
# Please note that Sourcery G++ support covers only your use
# of the original, validated binaries provided as part of
# Sourcery G++ -- and specifically does not cover either the
# process of rebuilding a component or the use of any binaries
# you may build.  In addition, if you rebuild any component,
# you must not use the --with-pkgversion and --with-bugurl
# configuration options that embed CodeSourcery trademarks in
# the resulting binary; see the "CodeSourcery Trademarks"
# section in the Sourcery G++ Software License Agreement.
set -e
inform_fd=2 
exec < /dev/null

check_status() {
    local status="$?"
    if [ "$status" -ne 0 ]; then
	return "$status"
    fi
}

check_pipe() {
    local -a status=("${PIPESTATUS[@]}")
    local limit=$1
    local ix
    
    if [ -z "$limit" ] ; then
	limit="${#status[@]}"
    fi
    for ((ix=0; ix != $limit ; ix++)); do
	if [ "${status[$ix]}" != "0" ] ; then
	    return "${status[$ix]}"
	fi
    done
}

error () {
    echo "$script: error: $@" >& $inform_fd
    exit 1
}

warning () {
    echo "$script: warning: $@" >& $inform_fd
}

verbose () {
    if $gnu_verbose; then
	echo "$script: $@" >& $inform_fd
    fi
}

copy_dir() {
    mkdir -p "$2"

    (cd "$1" && tar cf - .) | (cd "$2" && tar xf -)
    check_pipe
}

copy_dir_clean() {
    mkdir -p "$2"
    (cd "$1" && tar cf - \
	--exclude=CVS --exclude=.svn --exclude=.pc \
	--exclude="*~" --exclude=".#*" \
	--exclude="*.orig" --exclude="*.rej" \
	.) | (cd "$2" && tar xf -)
    check_pipe
}

update_dir_clean() {
    mkdir -p "$2"


    (cd "$1" && tar cf - \
	--exclude=CVS --exclude=.svn --exclude=.pc \
	--exclude="*~" --exclude=".#*" \
	--exclude="*.orig" --exclude="*.rej" \
	--after-date="$3" \
	. 2> /dev/null) | (cd "$2" && tar xf -)
    check_pipe
}

copy_dir_exclude() {
    local source="$1"
    local dest="$2"
    local excl="$3"
    shift 3
    mkdir -p "$dest"
    (cd "$source" && tar cfX - "$excl" "$@") | (cd "$dest" && tar xf -)
    check_pipe
}

copy_dir_only() {
    local source="$1"
    local dest="$2"
    shift 2
    mkdir -p "$dest"
    (cd "$source" && tar cf - "$@") | (cd "$dest" && tar xf -)
    check_pipe
}

clean_environment() {
    local env_var_list
    local var




    unset BASH_ENV CDPATH POSIXLY_CORRECT TMOUT

    env_var_list=$(export | \
	grep '^declare -x ' | \
	sed -e 's/^declare -x //' -e 's/=.*//')

    for var in $env_var_list; do
	case $var in
	    CSL_SCRIPTDIR|HOME|LOGNAME|PWD|SHELL|SHLVL|SSH_*|TERM|USER)


		;;
	    LD_LIBRARY_PATH|PATH| \
		QMTEST_CLASS_PATH| \
		FLEXLM_NO_CKOUT_INSTALL_LIC|LM_APP_DISABLE_CACHE_READ)


		;;
	    *_LICENSE_FILE)












		if [ "" ]; then
		    local license_file_envvar
		    license_file_envvar=

		    if [ "$var" != "$license_file_envvar" ]; then
			export -n "$var" || true
		    fi
		else
		    export -n "$var" || true
		fi
		;;
	    *)

		export -n "$var" || true
		;;
	esac
    done


    export LANG=C
    export LC_ALL=C


    export CVS_RSH=ssh



    export SHELL=$BASH
    export CONFIG_SHELL=$BASH
}

pushenv() {
    pushenv_level=$(($pushenv_level + 1))
    eval pushenv_vars_${pushenv_level}=
}


pushenv_level=0
pushenv_vars_0=



pushenvvar() {
    local pushenv_var="$1"
    local pushenv_newval="$2"
    eval local pushenv_oldval=\"\$$pushenv_var\"
    eval local pushenv_oldset=\"\${$pushenv_var+set}\"
    local pushenv_save_var=saved_${pushenv_level}_${pushenv_var}
    local pushenv_savep_var=savedp_${pushenv_level}_${pushenv_var}
    eval local pushenv_save_set=\"\${$pushenv_savep_var+set}\"
    if [ "$pushenv_save_set" = "set" ]; then
	error "Pushing $pushenv_var more than once at level $pushenv_level"
    fi
    if [ "$pushenv_oldset" = "set" ]; then
	eval $pushenv_save_var=\"\$pushenv_oldval\"
    else
	unset $pushenv_save_var
    fi
    eval $pushenv_savep_var=1
    eval export $pushenv_var=\"\$pushenv_newval\"
    local pushenv_list_var=pushenv_vars_${pushenv_level}
    eval $pushenv_list_var=\"\$$pushenv_list_var \$pushenv_var\"
}

prependenvvar() {
    local pushenv_var="$1"
    local pushenv_newval="$2"
    eval local pushenv_oldval=\"\$$pushenv_var\"
    pushenvvar "$pushenv_var" "$pushenv_newval$pushenv_oldval"
}

popenv() {
    local pushenv_var=
    eval local pushenv_vars=\"\$pushenv_vars_${pushenv_level}\"
    for pushenv_var in $pushenv_vars; do
	local pushenv_save_var=saved_${pushenv_level}_${pushenv_var}
	local pushenv_savep_var=savedp_${pushenv_level}_${pushenv_var}
	eval local pushenv_save_val=\"\$$pushenv_save_var\"
	eval local pushenv_save_set=\"\${$pushenv_save_var+set}\"
	unset $pushenv_save_var
	unset $pushenv_savep_var
	if [ "$pushenv_save_set" = "set" ]; then
	    eval export $pushenv_var=\"\$pushenv_save_val\"
	else
	    unset $pushenv_var
	fi
    done
    unset pushenv_vars_${pushenv_level}
    if [ "$pushenv_level" = "0" ]; then
	error "Popping environment level 0"
    else
	pushenv_level=$(($pushenv_level - 1))
    fi
}

prepend_path() {
    if $(eval "test -n \"\$$1\""); then
	prependenvvar "$1" "$2:"
    else
	prependenvvar "$1" "$2"
    fi
}
pushenvvar CSL_SCRIPTDIR /scratch/paul/symbian/src/scripts-trunk
pushenvvar PATH /usr/local/tools/gcc-3.4.0/bin:/bin:/usr/bin
pushenvvar LD_LIBRARY_PATH /usr/local/tools/gcc-3.4.0/lib64:/usr/local/tools/gcc-3.4.0/lib
pushenvvar QMTEST_CLASS_PATH QMTEST_CLASS_PATH
clean_environment
# task [001/067] /init/dirs
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
mkdir -p /scratch/paul/symbian/obj
mkdir -p /scratch/paul/symbian/install
mkdir -p /scratch/paul/symbian/pkg
mkdir -p /scratch/paul/symbian/logs
mkdir -p /scratch/paul/symbian/install/share/doc/arm-2007q3-52-arm-none-symbianelf/html
mkdir -p /scratch/paul/symbian/install/share/doc/arm-2007q3-52-arm-none-symbianelf/pdf
popenv

# task [002/067] /init/cleanup
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/paul/symbian/pkg/arm-2007q3-52-arm-none-symbianelf.src.tar.bz2 /scratch/paul/symbian/pkg/arm-2007q3-52-arm-none-symbianelf.backup.tar.bz2
popenv

# task [003/067] /init/source_package/binutils
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/paul/symbian/obj/pkg-2007q3-52-arm-none-symbianelf/arm-2007q3-52-arm-none-symbianelf/binutils-2007q3-52.tar.bz2
mkdir -p /scratch/paul/symbian/obj/pkg-2007q3-52-arm-none-symbianelf/arm-2007q3-52-arm-none-symbianelf
pushd /scratch/paul/symbian/src
tar cf /scratch/paul/symbian/obj/pkg-2007q3-52-arm-none-symbianelf/arm-2007q3-52-arm-none-symbianelf/binutils-2007q3-52.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' binutils-stable
popd
popenv

# task [004/067] /init/source_package/gcc
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/paul/symbian/obj/pkg-2007q3-52-arm-none-symbianelf/arm-2007q3-52-arm-none-symbianelf/gcc-2007q3-52.tar.bz2
mkdir -p /scratch/paul/symbian/obj/pkg-2007q3-52-arm-none-symbianelf/arm-2007q3-52-arm-none-symbianelf
pushd /scratch/paul/symbian/src
tar cf /scratch/paul/symbian/obj/pkg-2007q3-52-arm-none-symbianelf/arm-2007q3-52-arm-none-symbianelf/gcc-2007q3-52.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' gcc-4.2
popd
popenv

# task [005/067] /init/source_package/getting_started
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/paul/symbian/obj/pkg-2007q3-52-arm-none-symbianelf/arm-2007q3-52-arm-none-symbianelf.backup/getting_started-2007q3-52.tar.bz2
mkdir -p /scratch/paul/symbian/obj/pkg-2007q3-52-arm-none-symbianelf/arm-2007q3-52-arm-none-symbianelf.backup
pushd /scratch/paul/symbian/src
tar cf /scratch/paul/symbian/obj/pkg-2007q3-52-arm-none-symbianelf/arm-2007q3-52-arm-none-symbianelf.backup/getting_started-2007q3-52.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' getting-started-stable
popd
popenv

# task [006/067] /init/source_package/installanywhere
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/paul/symbian/obj/pkg-2007q3-52-arm-none-symbianelf/arm-2007q3-52-arm-none-symbianelf.backup/installanywhere-2007q3-52.tar.bz2
mkdir -p /scratch/paul/symbian/obj/pkg-2007q3-52-arm-none-symbianelf/arm-2007q3-52-arm-none-symbianelf.backup
pushd /scratch/paul/symbian/src
tar cf /scratch/paul/symbian/obj/pkg-2007q3-52-arm-none-symbianelf/arm-2007q3-52-arm-none-symbianelf.backup/installanywhere-2007q3-52.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' installanywhere-stable
popd
popenv

# task [007/067] /init/source_package/dejagnu_boards
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/paul/symbian/obj/pkg-2007q3-52-arm-none-symbianelf/arm-2007q3-52-arm-none-symbianelf.backup/dejagnu_boards-2007q3-52.tar.bz2
mkdir -p /scratch/paul/symbian/obj/pkg-2007q3-52-arm-none-symbianelf/arm-2007q3-52-arm-none-symbianelf.backup
pushd /scratch/paul/symbian/src
tar cf /scratch/paul/symbian/obj/pkg-2007q3-52-arm-none-symbianelf/arm-2007q3-52-arm-none-symbianelf.backup/dejagnu_boards-2007q3-52.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' dejagnu-boards-trunk
popd
popenv

# task [008/067] /init/source_package/scripts
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/paul/symbian/obj/pkg-2007q3-52-arm-none-symbianelf/arm-2007q3-52-arm-none-symbianelf.backup/scripts-2007q3-52.tar.bz2
mkdir -p /scratch/paul/symbian/obj/pkg-2007q3-52-arm-none-symbianelf/arm-2007q3-52-arm-none-symbianelf.backup
pushd /scratch/paul/symbian/src
tar cf /scratch/paul/symbian/obj/pkg-2007q3-52-arm-none-symbianelf/arm-2007q3-52-arm-none-symbianelf.backup/scripts-2007q3-52.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' scripts-trunk
popd
popenv

# task [009/067] /init/source_package/xfails
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/paul/symbian/obj/pkg-2007q3-52-arm-none-symbianelf/arm-2007q3-52-arm-none-symbianelf.backup/xfails-2007q3-52.tar.bz2
mkdir -p /scratch/paul/symbian/obj/pkg-2007q3-52-arm-none-symbianelf/arm-2007q3-52-arm-none-symbianelf.backup
pushd /scratch/paul/symbian/src
tar cf /scratch/paul/symbian/obj/pkg-2007q3-52-arm-none-symbianelf/arm-2007q3-52-arm-none-symbianelf.backup/xfails-2007q3-52.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' xfails-trunk
popd
popenv

# task [010/067] /init/source_package/make
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/paul/symbian/obj/pkg-2007q3-52-arm-none-symbianelf/arm-2007q3-52-arm-none-symbianelf/make-2007q3-52.tar.bz2
mkdir -p /scratch/paul/symbian/obj/pkg-2007q3-52-arm-none-symbianelf/arm-2007q3-52-arm-none-symbianelf
pushd /scratch/paul/symbian/src
tar cf /scratch/paul/symbian/obj/pkg-2007q3-52-arm-none-symbianelf/arm-2007q3-52-arm-none-symbianelf/make-2007q3-52.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' make-3.81
popd
popenv

# task [011/067] /init/source_package/coreutils
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/paul/symbian/obj/pkg-2007q3-52-arm-none-symbianelf/arm-2007q3-52-arm-none-symbianelf/coreutils-2007q3-52.tar.bz2
mkdir -p /scratch/paul/symbian/obj/pkg-2007q3-52-arm-none-symbianelf/arm-2007q3-52-arm-none-symbianelf
pushd /scratch/paul/symbian/src
tar cf /scratch/paul/symbian/obj/pkg-2007q3-52-arm-none-symbianelf/arm-2007q3-52-arm-none-symbianelf/coreutils-2007q3-52.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' coreutils-5.94
popd
popenv

# task [012/067] /init/source_package/libiconv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/paul/symbian/obj/pkg-2007q3-52-arm-none-symbianelf/arm-2007q3-52-arm-none-symbianelf/libiconv-2007q3-52.tar.bz2
mkdir -p /scratch/paul/symbian/obj/pkg-2007q3-52-arm-none-symbianelf/arm-2007q3-52-arm-none-symbianelf
pushd /scratch/paul/symbian/src
tar cf /scratch/paul/symbian/obj/pkg-2007q3-52-arm-none-symbianelf/arm-2007q3-52-arm-none-symbianelf/libiconv-2007q3-52.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' libiconv-1.11
popd
popenv

# task [013/067] /init/source_package/csl_docbook
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/paul/symbian/obj/pkg-2007q3-52-arm-none-symbianelf/arm-2007q3-52-arm-none-symbianelf.backup/csl_docbook-2007q3-52.tar.bz2
mkdir -p /scratch/paul/symbian/obj/pkg-2007q3-52-arm-none-symbianelf/arm-2007q3-52-arm-none-symbianelf.backup
pushd /scratch/paul/symbian/src
tar cf /scratch/paul/symbian/obj/pkg-2007q3-52-arm-none-symbianelf/arm-2007q3-52-arm-none-symbianelf.backup/csl_docbook-2007q3-52.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' csl-docbook-trunk
popd
popenv

# task [014/067] /i686-pc-linux-gnu/host_cleanup
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/symbian/install/bin
popenv

# task [015/067] /i686-pc-linux-gnu/toolchain/binutils/copy
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/symbian/install/bin
pushenv
rm -rf /scratch/paul/symbian/obj/binutils-src-2007q3-52-arm-none-symbianelf-i686-pc-linux-gnu
copy_dir_clean /scratch/paul/symbian/src/binutils-stable /scratch/paul/symbian/obj/binutils-src-2007q3-52-arm-none-symbianelf-i686-pc-linux-gnu
chmod -R u+w /scratch/paul/symbian/obj/binutils-src-2007q3-52-arm-none-symbianelf-i686-pc-linux-gnu
touch /scratch/paul/symbian/obj/binutils-src-2007q3-52-arm-none-symbianelf-i686-pc-linux-gnu/.gnu-stamp
popenv
popenv

# task [016/067] /i686-pc-linux-gnu/toolchain/binutils/configure
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/symbian/install/bin
pushenv
rm -rf /scratch/paul/symbian/obj/binutils-2007q3-52-arm-none-symbianelf-i686-pc-linux-gnu
mkdir -p /scratch/paul/symbian/obj/binutils-2007q3-52-arm-none-symbianelf-i686-pc-linux-gnu
pushd /scratch/paul/symbian/obj/binutils-2007q3-52-arm-none-symbianelf-i686-pc-linux-gnu
/scratch/paul/symbian/obj/binutils-src-2007q3-52-arm-none-symbianelf-i686-pc-linux-gnu/configure --build=i686-pc-linux-gnu --target=arm-none-symbianelf --prefix=/opt/codesourcery --host=i686-pc-linux-gnu '--with-pkgversion=CodeSourcery Sourcery G++ Lite 2007q3-52' --with-bugurl=https://support.codesourcery.com/GNUToolchain/ --disable-nls --enable-poison-system-directories
popd
popenv
popenv

# task [017/067] /i686-pc-linux-gnu/toolchain/binutils/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/symbian/install/bin
pushenv
pushd /scratch/paul/symbian/obj/binutils-2007q3-52-arm-none-symbianelf-i686-pc-linux-gnu
make -j4
popd
popenv
popenv

# task [018/067] /i686-pc-linux-gnu/toolchain/binutils/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/symbian/install/bin
pushenv
pushd /scratch/paul/symbian/obj/binutils-2007q3-52-arm-none-symbianelf-i686-pc-linux-gnu
make install prefix=/scratch/paul/symbian/install exec_prefix=/scratch/paul/symbian/install libdir=/scratch/paul/symbian/install/lib htmldir=/scratch/paul/symbian/install/share/doc/arm-2007q3-52-arm-none-symbianelf/html pdfdir=/scratch/paul/symbian/install/share/doc/arm-2007q3-52-arm-none-symbianelf/pdf infodir=/scratch/paul/symbian/install/share/doc/arm-2007q3-52-arm-none-symbianelf/info mandir=/scratch/paul/symbian/install/share/doc/arm-2007q3-52-arm-none-symbianelf/man datadir=/scratch/paul/symbian/install/share
popd
popenv
popenv

# task [019/067] /i686-pc-linux-gnu/toolchain/binutils/postinstall
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/symbian/install/bin
pushenv
pushd /scratch/paul/symbian/install
rm -f lib/libiberty.a
rm -f 'bin/*gccbug'
rm -f 'bin/gccbug*'
rm -f lib/charset.alias
popd
copy_dir_clean /scratch/paul/symbian/src/binutils-stable/include /scratch/paul/symbian/obj/host-binutils-2007q3-52-arm-none-symbianelf-i686-pc-linux-gnu/usr/include
chmod -R u+w /scratch/paul/symbian/obj/host-binutils-2007q3-52-arm-none-symbianelf-i686-pc-linux-gnu/usr/include
mkdir -p /scratch/paul/symbian/obj/host-binutils-2007q3-52-arm-none-symbianelf-i686-pc-linux-gnu/usr/lib
cp /scratch/paul/symbian/obj/binutils-2007q3-52-arm-none-symbianelf-i686-pc-linux-gnu/libiberty/libiberty.a /scratch/paul/symbian/obj/host-binutils-2007q3-52-arm-none-symbianelf-i686-pc-linux-gnu/usr/lib
cp /scratch/paul/symbian/obj/binutils-2007q3-52-arm-none-symbianelf-i686-pc-linux-gnu/bfd/.libs/libbfd.a /scratch/paul/symbian/obj/host-binutils-2007q3-52-arm-none-symbianelf-i686-pc-linux-gnu/usr/lib
cp /scratch/paul/symbian/obj/binutils-2007q3-52-arm-none-symbianelf-i686-pc-linux-gnu/bfd/bfd.h /scratch/paul/symbian/obj/host-binutils-2007q3-52-arm-none-symbianelf-i686-pc-linux-gnu/usr/include
cp /scratch/paul/symbian/src/binutils-stable/bfd/elf-bfd.h /scratch/paul/symbian/obj/host-binutils-2007q3-52-arm-none-symbianelf-i686-pc-linux-gnu/usr/include
cp /scratch/paul/symbian/obj/binutils-2007q3-52-arm-none-symbianelf-i686-pc-linux-gnu/opcodes/.libs/libopcodes.a /scratch/paul/symbian/obj/host-binutils-2007q3-52-arm-none-symbianelf-i686-pc-linux-gnu/usr/lib
popenv
popenv

# task [020/067] /i686-pc-linux-gnu/toolchain/gcc_final/configure
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/symbian/install/bin
pushenv
pushenvvar AR_FOR_TARGET arm-none-symbianelf-ar
pushenvvar NM_FOR_TARGET arm-none-symbianelf-nm
pushenvvar OBJDUMP_FOR_TARET arm-none-symbianelf-objdump
pushenvvar STRIP_FOR_TARGET arm-none-symbianelf-strip
rm -rf /scratch/paul/symbian/obj/gcc-2007q3-52-arm-none-symbianelf-i686-pc-linux-gnu
mkdir -p /scratch/paul/symbian/obj/gcc-2007q3-52-arm-none-symbianelf-i686-pc-linux-gnu
pushd /scratch/paul/symbian/obj/gcc-2007q3-52-arm-none-symbianelf-i686-pc-linux-gnu
/scratch/paul/symbian/src/gcc-4.2/configure --build=i686-pc-linux-gnu --host=i686-pc-linux-gnu --target=arm-none-symbianelf --enable-threads --disable-libmudflap --disable-libssp --disable-libgomp --disable-libstdcxx-pch --with-gnu-as --with-gnu-ld --enable-languages=c,c++ --enable-shared '--with-pkgversion=CodeSourcery Sourcery G++ Lite 2007q3-52' --with-bugurl=https://support.codesourcery.com/GNUToolchain/ --disable-nls --prefix=/opt/codesourcery --enable-poison-system-directories --with-build-time-tools=/scratch/paul/symbian/install/arm-none-symbianelf/bin --with-build-time-tools=/scratch/paul/symbian/install/arm-none-symbianelf/bin
popd
popenv
popenv

# task [021/067] /i686-pc-linux-gnu/toolchain/gcc_final/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/symbian/install/bin
pushenv
pushenvvar AR_FOR_TARGET arm-none-symbianelf-ar
pushenvvar NM_FOR_TARGET arm-none-symbianelf-nm
pushenvvar OBJDUMP_FOR_TARET arm-none-symbianelf-objdump
pushenvvar STRIP_FOR_TARGET arm-none-symbianelf-strip
pushd /scratch/paul/symbian/obj/gcc-2007q3-52-arm-none-symbianelf-i686-pc-linux-gnu
make -j4
popd
popenv
popenv

# task [022/067] /i686-pc-linux-gnu/toolchain/gcc_final/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/symbian/install/bin
pushenv
pushenvvar AR_FOR_TARGET arm-none-symbianelf-ar
pushenvvar NM_FOR_TARGET arm-none-symbianelf-nm
pushenvvar OBJDUMP_FOR_TARET arm-none-symbianelf-objdump
pushenvvar STRIP_FOR_TARGET arm-none-symbianelf-strip
pushd /scratch/paul/symbian/obj/gcc-2007q3-52-arm-none-symbianelf-i686-pc-linux-gnu
make prefix=/scratch/paul/symbian/install exec_prefix=/scratch/paul/symbian/install libdir=/scratch/paul/symbian/install/lib htmldir=/scratch/paul/symbian/install/share/doc/arm-2007q3-52-arm-none-symbianelf/html pdfdir=/scratch/paul/symbian/install/share/doc/arm-2007q3-52-arm-none-symbianelf/pdf infodir=/scratch/paul/symbian/install/share/doc/arm-2007q3-52-arm-none-symbianelf/info mandir=/scratch/paul/symbian/install/share/doc/arm-2007q3-52-arm-none-symbianelf/man install
popd
popenv
popenv

# task [023/067] /i686-pc-linux-gnu/toolchain/gcc_final/postinstall
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/symbian/install/bin
pushenv
pushenvvar AR_FOR_TARGET arm-none-symbianelf-ar
pushenvvar NM_FOR_TARGET arm-none-symbianelf-nm
pushenvvar OBJDUMP_FOR_TARET arm-none-symbianelf-objdump
pushenvvar STRIP_FOR_TARGET arm-none-symbianelf-strip
pushd /scratch/paul/symbian/install
rm -f lib/libiberty.a
rm -f bin/arm-none-symbianelf-gccbug
rm -f 'bin/gccbug*'
rm -f lib/charset.alias
popd
popenv
popenv

# task [024/067] /i686-pc-linux-gnu/getting_started/configure
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/symbian/install/bin
pushenv
rm -rf /scratch/paul/symbian/obj/getting_started-2007q3-52-arm-none-symbianelf-i686-pc-linux-gnu
mkdir -p /scratch/paul/symbian/obj/getting_started-2007q3-52-arm-none-symbianelf-i686-pc-linux-gnu
pushd /scratch/paul/symbian/obj/getting_started-2007q3-52-arm-none-symbianelf-i686-pc-linux-gnu
/scratch/paul/symbian/src/getting-started-stable/configure --build=i686-pc-linux-gnu --target=arm-none-symbianelf --prefix=/opt/codesourcery --host=i686-pc-linux-gnu --disable-nls --with-release-config=4.2-arm-none-symbianelf-lite '--with-components=binutils gcc getting_started installanywhere branding contents comparison dejagnu_boards scripts xfails make coreutils libiconv csl_docbook eclipse' '--with-host_os-name=IA32 GNU/Linux' --with-target-arch-name=ARM --with-target-os-name=SymbianOS --with-intermediate-dir=/scratch/paul/symbian/obj/getting_started-2007q3-52-arm-none-symbianelf --with-csl-docbook=/scratch/paul/symbian/src/csl-docbook-trunk --with-version-string=2007q3-52 '--with-brand=Sourcery G++ Lite' '--with-xml-catalog-files=/usr/local/tools/gcc-3.4.0/share/sgml/docbook/docbook-xsl/catalog.xml /etc/xml/catalog' --with-license=lite '--with-component-licenses= binutils=gpl3.0 gcc=gpl3.0 make=gpl2.0 coreutils=gpl2.0'
popd
popenv
popenv

# task [025/067] /i686-pc-linux-gnu/getting_started/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/symbian/install/bin
pushenv
pushd /scratch/paul/symbian/obj/getting_started-2007q3-52-arm-none-symbianelf-i686-pc-linux-gnu
make -j4
popd
popenv
popenv

# task [026/067] /i686-pc-linux-gnu/getting_started/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/symbian/install/bin
pushenv
pushd /scratch/paul/symbian/obj/getting_started-2007q3-52-arm-none-symbianelf-i686-pc-linux-gnu
make install prefix=/scratch/paul/symbian/install exec_prefix=/scratch/paul/symbian/install libdir=/scratch/paul/symbian/install/lib htmldir=/scratch/paul/symbian/install/share/doc/arm-2007q3-52-arm-none-symbianelf/html pdfdir=/scratch/paul/symbian/install/share/doc/arm-2007q3-52-arm-none-symbianelf/pdf infodir=/scratch/paul/symbian/install/share/doc/arm-2007q3-52-arm-none-symbianelf/info mandir=/scratch/paul/symbian/install/share/doc/arm-2007q3-52-arm-none-symbianelf/man datadir=/scratch/paul/symbian/install/share docdir=/scratch/paul/symbian/install/share/doc/arm-2007q3-52-arm-none-symbianelf
popd
popenv
popenv

# task [027/067] /i686-pc-linux-gnu/finalize_libc_installation
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/symbian/install/bin
popenv

# task [028/067] /i686-pc-linux-gnu/pretidy_installation
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/symbian/install/bin
pushd /scratch/paul/symbian/install
rm -f lib/libiberty.a
rm -f 'bin/*gccbug'
rm -f 'bin/gccbug*'
rm -f lib/charset.alias
popd
popenv

# task [029/067] /i686-pc-linux-gnu/remove_libtool_archives
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/symbian/install/bin
find /scratch/paul/symbian/install -name '*.la' -exec rm '{}' ';'
popenv

# task [030/067] /i686-pc-linux-gnu/remove_fixed_headers
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/symbian/install/bin
pushd /scratch/paul/symbian/install/lib/gcc/arm-none-symbianelf/4.2.1/include-fixed
popd
popenv

# task [031/067] /i686-pc-linux-gnu/strip_host_objects
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/symbian/install/bin
/usr/bin/strip /scratch/paul/symbian/install/bin/arm-none-symbianelf-addr2line
/usr/bin/strip /scratch/paul/symbian/install/bin/arm-none-symbianelf-ar
/usr/bin/strip /scratch/paul/symbian/install/bin/arm-none-symbianelf-as
/usr/bin/strip /scratch/paul/symbian/install/bin/arm-none-symbianelf-c++
/usr/bin/strip /scratch/paul/symbian/install/bin/arm-none-symbianelf-c++filt
/usr/bin/strip /scratch/paul/symbian/install/bin/arm-none-symbianelf-cpp
/usr/bin/strip /scratch/paul/symbian/install/bin/arm-none-symbianelf-g++
/usr/bin/strip /scratch/paul/symbian/install/bin/arm-none-symbianelf-gcc
/usr/bin/strip /scratch/paul/symbian/install/bin/arm-none-symbianelf-gcc-4.2.1
/usr/bin/strip /scratch/paul/symbian/install/bin/arm-none-symbianelf-gcov
/usr/bin/strip /scratch/paul/symbian/install/bin/arm-none-symbianelf-gprof
/usr/bin/strip /scratch/paul/symbian/install/bin/arm-none-symbianelf-ld
/usr/bin/strip /scratch/paul/symbian/install/bin/arm-none-symbianelf-nm
/usr/bin/strip /scratch/paul/symbian/install/bin/arm-none-symbianelf-objcopy
/usr/bin/strip /scratch/paul/symbian/install/bin/arm-none-symbianelf-objdump
/usr/bin/strip /scratch/paul/symbian/install/bin/arm-none-symbianelf-ranlib
/usr/bin/strip /scratch/paul/symbian/install/bin/arm-none-symbianelf-readelf
/usr/bin/strip /scratch/paul/symbian/install/bin/arm-none-symbianelf-size
/usr/bin/strip /scratch/paul/symbian/install/bin/arm-none-symbianelf-strings
/usr/bin/strip /scratch/paul/symbian/install/bin/arm-none-symbianelf-strip
/usr/bin/strip /scratch/paul/symbian/install/arm-none-symbianelf/bin/ar
/usr/bin/strip /scratch/paul/symbian/install/arm-none-symbianelf/bin/as
/usr/bin/strip /scratch/paul/symbian/install/arm-none-symbianelf/bin/c++
/usr/bin/strip /scratch/paul/symbian/install/arm-none-symbianelf/bin/g++
/usr/bin/strip /scratch/paul/symbian/install/arm-none-symbianelf/bin/gcc
/usr/bin/strip /scratch/paul/symbian/install/arm-none-symbianelf/bin/ld
/usr/bin/strip /scratch/paul/symbian/install/arm-none-symbianelf/bin/nm
/usr/bin/strip /scratch/paul/symbian/install/arm-none-symbianelf/bin/objcopy
/usr/bin/strip /scratch/paul/symbian/install/arm-none-symbianelf/bin/objdump
/usr/bin/strip /scratch/paul/symbian/install/arm-none-symbianelf/bin/ranlib
/usr/bin/strip /scratch/paul/symbian/install/arm-none-symbianelf/bin/strip
/usr/bin/strip /scratch/paul/symbian/install/libexec/gcc/arm-none-symbianelf/4.2.1/cc1
/usr/bin/strip /scratch/paul/symbian/install/libexec/gcc/arm-none-symbianelf/4.2.1/collect2
/usr/bin/strip /scratch/paul/symbian/install/libexec/gcc/arm-none-symbianelf/4.2.1/install-tools/fixincl
/usr/bin/strip /scratch/paul/symbian/install/libexec/gcc/arm-none-symbianelf/4.2.1/cc1plus
popenv

# task [032/067] /i686-pc-linux-gnu/strip_target_objects
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/symbian/install/bin
arm-none-symbianelf-objcopy -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc -R .comment -R .note /scratch/paul/symbian/install/arm-none-symbianelf/lib/mfloat-abi=softfp/libsupc++.a || true
arm-none-symbianelf-objcopy -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc -R .comment -R .note /scratch/paul/symbian/install/arm-none-symbianelf/lib/libsupc++.a || true
arm-none-symbianelf-objcopy -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc -R .comment -R .note /scratch/paul/symbian/install/lib/gcc/arm-none-symbianelf/4.2.1/libgcc.a || true
arm-none-symbianelf-objcopy -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc -R .comment -R .note /scratch/paul/symbian/install/lib/gcc/arm-none-symbianelf/4.2.1/libgcov.a || true
arm-none-symbianelf-objcopy -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc -R .comment -R .note /scratch/paul/symbian/install/lib/gcc/arm-none-symbianelf/4.2.1/softfp/libgcc.a || true
arm-none-symbianelf-objcopy -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc -R .comment -R .note /scratch/paul/symbian/install/lib/gcc/arm-none-symbianelf/4.2.1/softfp/libgcov.a || true
popenv

# task [033/067] /i686-pc-linux-gnu/package_tbz2
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/symbian/install/bin
rm -f /scratch/paul/symbian/pkg/arm-2007q3-52-arm-none-symbianelf-i686-pc-linux-gnu.tar.bz2
pushd /scratch/paul/symbian/obj
rm -f arm-2007q3
ln -s /scratch/paul/symbian/install arm-2007q3
tar cjf /scratch/paul/symbian/pkg/arm-2007q3-52-arm-none-symbianelf-i686-pc-linux-gnu.tar.bz2 --owner=0 --group=0 --exclude=host-i686-pc-linux-gnu --exclude=host-i686-mingw32 arm-2007q3/arm-none-symbianelf arm-2007q3/bin arm-2007q3/include arm-2007q3/lib arm-2007q3/libexec arm-2007q3/share
rm -f arm-2007q3
popd
popenv

# task [034/067] /i686-pc-linux-gnu/package_rpm
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/symbian/install/bin
/scratch/paul/symbian/src/scripts-trunk/gnu-rpm-inst -i /scratch/paul/symbian/install -l /scratch/paul/symbian/logs -o /scratch/paul/symbian/obj -p /scratch/paul/symbian/pkg -s /scratch/paul/symbian/src -T /scratch/paul/symbian/testlogs -h i686-pc-linux-gnu -b /scratch/paul/symbian/install/bin 4.2-arm-none-symbianelf-lite
popenv

# task [035/067] /i686-pc-linux-gnu/package_installanywhere
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/symbian/install/bin
/scratch/paul/symbian/src/scripts-trunk/gnu-installanywhere -i /scratch/paul/symbian/install -l /scratch/paul/symbian/logs -o /scratch/paul/symbian/obj -p /scratch/paul/symbian/pkg -s /scratch/paul/symbian/src -T /scratch/paul/symbian/testlogs -h i686-pc-linux-gnu -f /scratch/paul/symbian/obj/getting_started-2007q3-52-arm-none-symbianelf/license.html 4.2-arm-none-symbianelf-lite
popenv

# task [036/067] /i686-mingw32/host_cleanup
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/symbian/obj/tools-i686-pc-linux-gnu-2007q3-52-arm-none-symbianelf-i686-mingw32/bin
popenv

# task [037/067] /i686-mingw32/host_unpack
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/symbian/obj/tools-i686-pc-linux-gnu-2007q3-52-arm-none-symbianelf-i686-mingw32/bin
rm -rf /scratch/paul/symbian/obj/tools-i686-pc-linux-gnu-2007q3-52-arm-none-symbianelf-i686-mingw32
mkdir /scratch/paul/symbian/obj/tools-i686-pc-linux-gnu-2007q3-52-arm-none-symbianelf-i686-mingw32
pushd /scratch/paul/symbian/obj/tools-i686-pc-linux-gnu-2007q3-52-arm-none-symbianelf-i686-mingw32
ln -s . arm-2007q3
tar xf /scratch/paul/symbian/pkg/arm-2007q3-52-arm-none-symbianelf-i686-pc-linux-gnu.tar.bz2 --bzip2
rm arm-2007q3
popd
popenv

# task [038/067] /i686-mingw32/libiconv/configure
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/symbian/obj/tools-i686-pc-linux-gnu-2007q3-52-arm-none-symbianelf-i686-mingw32/bin
pushenv
rm -rf /scratch/paul/symbian/obj/libiconv-2007q3-52-arm-none-symbianelf-i686-mingw32
mkdir -p /scratch/paul/symbian/obj/libiconv-2007q3-52-arm-none-symbianelf-i686-mingw32
pushd /scratch/paul/symbian/obj/libiconv-2007q3-52-arm-none-symbianelf-i686-mingw32
/scratch/paul/symbian/src/libiconv-1.11/configure --build=i686-pc-linux-gnu --target=arm-none-symbianelf --prefix=/scratch/paul/symbian/obj/host-libs-2007q3-52-arm-none-symbianelf-i686-mingw32/usr --disable-shared --host=i686-mingw32 --disable-nls
popd
popenv
popenv

# task [039/067] /i686-mingw32/libiconv/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/symbian/obj/tools-i686-pc-linux-gnu-2007q3-52-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushd /scratch/paul/symbian/obj/libiconv-2007q3-52-arm-none-symbianelf-i686-mingw32
make -j1
popd
popenv
popenv

# task [040/067] /i686-mingw32/libiconv/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/symbian/obj/tools-i686-pc-linux-gnu-2007q3-52-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushd /scratch/paul/symbian/obj/libiconv-2007q3-52-arm-none-symbianelf-i686-mingw32
make install
popd
popenv
popenv

# task [041/067] /i686-mingw32/make/copy
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/symbian/obj/tools-i686-pc-linux-gnu-2007q3-52-arm-none-symbianelf-i686-mingw32/bin
pushenv
rm -rf /scratch/paul/symbian/obj/make-src-2007q3-52-arm-none-symbianelf-i686-mingw32
copy_dir_clean /scratch/paul/symbian/src/make-3.81 /scratch/paul/symbian/obj/make-src-2007q3-52-arm-none-symbianelf-i686-mingw32
chmod -R u+w /scratch/paul/symbian/obj/make-src-2007q3-52-arm-none-symbianelf-i686-mingw32
touch /scratch/paul/symbian/obj/make-src-2007q3-52-arm-none-symbianelf-i686-mingw32/.gnu-stamp
popenv
popenv

# task [042/067] /i686-mingw32/make/configure
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/symbian/obj/tools-i686-pc-linux-gnu-2007q3-52-arm-none-symbianelf-i686-mingw32/bin
pushenv
rm -rf /scratch/paul/symbian/obj/make-2007q3-52-arm-none-symbianelf-i686-mingw32
mkdir -p /scratch/paul/symbian/obj/make-2007q3-52-arm-none-symbianelf-i686-mingw32
pushd /scratch/paul/symbian/obj/make-2007q3-52-arm-none-symbianelf-i686-mingw32
/scratch/paul/symbian/obj/make-src-2007q3-52-arm-none-symbianelf-i686-mingw32/configure --build=i686-pc-linux-gnu --target=arm-none-symbianelf --prefix=/opt/codesourcery --host=i686-mingw32 '--with-pkgversion=CodeSourcery Sourcery G++ Lite 2007q3-52' --disable-nls --program-prefix=cs-
popd
popenv
popenv

# task [043/067] /i686-mingw32/make/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/symbian/obj/tools-i686-pc-linux-gnu-2007q3-52-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushd /scratch/paul/symbian/obj/make-2007q3-52-arm-none-symbianelf-i686-mingw32
make -j4
popd
popenv
popenv

# task [044/067] /i686-mingw32/make/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/symbian/obj/tools-i686-pc-linux-gnu-2007q3-52-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushd /scratch/paul/symbian/obj/make-2007q3-52-arm-none-symbianelf-i686-mingw32
make install prefix=/scratch/paul/symbian/install/host-i686-mingw32 exec_prefix=/scratch/paul/symbian/install/host-i686-mingw32 libdir=/scratch/paul/symbian/install/host-i686-mingw32/lib htmldir=/scratch/paul/symbian/install/host-i686-mingw32/share/doc/arm-2007q3-52-arm-none-symbianelf/html pdfdir=/scratch/paul/symbian/install/host-i686-mingw32/share/doc/arm-2007q3-52-arm-none-symbianelf/pdf infodir=/scratch/paul/symbian/install/host-i686-mingw32/share/doc/arm-2007q3-52-arm-none-symbianelf/info mandir=/scratch/paul/symbian/install/host-i686-mingw32/share/doc/arm-2007q3-52-arm-none-symbianelf/man datadir=/scratch/paul/symbian/install/host-i686-mingw32/share
popd
popenv
popenv

# task [045/067] /i686-mingw32/coreutils/copy
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/symbian/obj/tools-i686-pc-linux-gnu-2007q3-52-arm-none-symbianelf-i686-mingw32/bin
pushenv
rm -rf /scratch/paul/symbian/obj/coreutils-src-2007q3-52-arm-none-symbianelf-i686-mingw32
copy_dir_clean /scratch/paul/symbian/src/coreutils-5.94 /scratch/paul/symbian/obj/coreutils-src-2007q3-52-arm-none-symbianelf-i686-mingw32
chmod -R u+w /scratch/paul/symbian/obj/coreutils-src-2007q3-52-arm-none-symbianelf-i686-mingw32
touch /scratch/paul/symbian/obj/coreutils-src-2007q3-52-arm-none-symbianelf-i686-mingw32/.gnu-stamp
popenv
popenv

# task [046/067] /i686-mingw32/coreutils/configure
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/symbian/obj/tools-i686-pc-linux-gnu-2007q3-52-arm-none-symbianelf-i686-mingw32/bin
pushenv
rm -rf /scratch/paul/symbian/obj/coreutils-2007q3-52-arm-none-symbianelf-i686-mingw32
mkdir -p /scratch/paul/symbian/obj/coreutils-2007q3-52-arm-none-symbianelf-i686-mingw32
pushd /scratch/paul/symbian/obj/coreutils-2007q3-52-arm-none-symbianelf-i686-mingw32
/scratch/paul/symbian/obj/coreutils-src-2007q3-52-arm-none-symbianelf-i686-mingw32/configure --build=i686-pc-linux-gnu --target=arm-none-symbianelf --prefix=/opt/codesourcery --host=i686-mingw32 '--with-pkgversion=CodeSourcery Sourcery G++ Lite 2007q3-52' --disable-nls --program-prefix=cs-
popd
popenv
popenv

# task [047/067] /i686-mingw32/coreutils/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/symbian/obj/tools-i686-pc-linux-gnu-2007q3-52-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushd /scratch/paul/symbian/obj/coreutils-2007q3-52-arm-none-symbianelf-i686-mingw32
make -j4
popd
popenv
popenv

# task [048/067] /i686-mingw32/coreutils/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/symbian/obj/tools-i686-pc-linux-gnu-2007q3-52-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushd /scratch/paul/symbian/obj/coreutils-2007q3-52-arm-none-symbianelf-i686-mingw32
make install prefix=/scratch/paul/symbian/install/host-i686-mingw32 exec_prefix=/scratch/paul/symbian/install/host-i686-mingw32 libdir=/scratch/paul/symbian/install/host-i686-mingw32/lib htmldir=/scratch/paul/symbian/install/host-i686-mingw32/share/doc/arm-2007q3-52-arm-none-symbianelf/html pdfdir=/scratch/paul/symbian/install/host-i686-mingw32/share/doc/arm-2007q3-52-arm-none-symbianelf/pdf infodir=/scratch/paul/symbian/install/host-i686-mingw32/share/doc/arm-2007q3-52-arm-none-symbianelf/info mandir=/scratch/paul/symbian/install/host-i686-mingw32/share/doc/arm-2007q3-52-arm-none-symbianelf/man datadir=/scratch/paul/symbian/install/host-i686-mingw32/share
popd
popenv
popenv

# task [049/067] /i686-mingw32/toolchain/binutils/copy
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/symbian/obj/tools-i686-pc-linux-gnu-2007q3-52-arm-none-symbianelf-i686-mingw32/bin
pushenv
rm -rf /scratch/paul/symbian/obj/binutils-src-2007q3-52-arm-none-symbianelf-i686-mingw32
copy_dir_clean /scratch/paul/symbian/src/binutils-stable /scratch/paul/symbian/obj/binutils-src-2007q3-52-arm-none-symbianelf-i686-mingw32
chmod -R u+w /scratch/paul/symbian/obj/binutils-src-2007q3-52-arm-none-symbianelf-i686-mingw32
touch /scratch/paul/symbian/obj/binutils-src-2007q3-52-arm-none-symbianelf-i686-mingw32/.gnu-stamp
popenv
popenv

# task [050/067] /i686-mingw32/toolchain/binutils/configure
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/symbian/obj/tools-i686-pc-linux-gnu-2007q3-52-arm-none-symbianelf-i686-mingw32/bin
pushenv
rm -rf /scratch/paul/symbian/obj/binutils-2007q3-52-arm-none-symbianelf-i686-mingw32
mkdir -p /scratch/paul/symbian/obj/binutils-2007q3-52-arm-none-symbianelf-i686-mingw32
pushd /scratch/paul/symbian/obj/binutils-2007q3-52-arm-none-symbianelf-i686-mingw32
/scratch/paul/symbian/obj/binutils-src-2007q3-52-arm-none-symbianelf-i686-mingw32/configure --build=i686-pc-linux-gnu --target=arm-none-symbianelf --prefix=/opt/codesourcery --host=i686-mingw32 '--with-pkgversion=CodeSourcery Sourcery G++ Lite 2007q3-52' --with-bugurl=https://support.codesourcery.com/GNUToolchain/ --disable-nls --enable-poison-system-directories
popd
popenv
popenv

# task [051/067] /i686-mingw32/toolchain/binutils/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/symbian/obj/tools-i686-pc-linux-gnu-2007q3-52-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushd /scratch/paul/symbian/obj/binutils-2007q3-52-arm-none-symbianelf-i686-mingw32
make -j4
popd
popenv
popenv

# task [052/067] /i686-mingw32/toolchain/binutils/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/symbian/obj/tools-i686-pc-linux-gnu-2007q3-52-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushd /scratch/paul/symbian/obj/binutils-2007q3-52-arm-none-symbianelf-i686-mingw32
make install prefix=/scratch/paul/symbian/install/host-i686-mingw32 exec_prefix=/scratch/paul/symbian/install/host-i686-mingw32 libdir=/scratch/paul/symbian/install/host-i686-mingw32/lib htmldir=/scratch/paul/symbian/install/host-i686-mingw32/share/doc/arm-2007q3-52-arm-none-symbianelf/html pdfdir=/scratch/paul/symbian/install/host-i686-mingw32/share/doc/arm-2007q3-52-arm-none-symbianelf/pdf infodir=/scratch/paul/symbian/install/host-i686-mingw32/share/doc/arm-2007q3-52-arm-none-symbianelf/info mandir=/scratch/paul/symbian/install/host-i686-mingw32/share/doc/arm-2007q3-52-arm-none-symbianelf/man datadir=/scratch/paul/symbian/install/host-i686-mingw32/share
popd
popenv
popenv

# task [053/067] /i686-mingw32/toolchain/binutils/postinstall
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/symbian/obj/tools-i686-pc-linux-gnu-2007q3-52-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushd /scratch/paul/symbian/install/host-i686-mingw32
rm -f lib/libiberty.a
rm -f 'bin/*gccbug'
rm -f 'bin/gccbug*'
rm -f lib/charset.alias
popd
copy_dir_clean /scratch/paul/symbian/src/binutils-stable/include /scratch/paul/symbian/obj/host-binutils-2007q3-52-arm-none-symbianelf-i686-mingw32/usr/include
chmod -R u+w /scratch/paul/symbian/obj/host-binutils-2007q3-52-arm-none-symbianelf-i686-mingw32/usr/include
mkdir -p /scratch/paul/symbian/obj/host-binutils-2007q3-52-arm-none-symbianelf-i686-mingw32/usr/lib
cp /scratch/paul/symbian/obj/binutils-2007q3-52-arm-none-symbianelf-i686-mingw32/libiberty/libiberty.a /scratch/paul/symbian/obj/host-binutils-2007q3-52-arm-none-symbianelf-i686-mingw32/usr/lib
cp /scratch/paul/symbian/obj/binutils-2007q3-52-arm-none-symbianelf-i686-mingw32/bfd/.libs/libbfd.a /scratch/paul/symbian/obj/host-binutils-2007q3-52-arm-none-symbianelf-i686-mingw32/usr/lib
cp /scratch/paul/symbian/obj/binutils-2007q3-52-arm-none-symbianelf-i686-mingw32/bfd/bfd.h /scratch/paul/symbian/obj/host-binutils-2007q3-52-arm-none-symbianelf-i686-mingw32/usr/include
cp /scratch/paul/symbian/src/binutils-stable/bfd/elf-bfd.h /scratch/paul/symbian/obj/host-binutils-2007q3-52-arm-none-symbianelf-i686-mingw32/usr/include
cp /scratch/paul/symbian/obj/binutils-2007q3-52-arm-none-symbianelf-i686-mingw32/opcodes/.libs/libopcodes.a /scratch/paul/symbian/obj/host-binutils-2007q3-52-arm-none-symbianelf-i686-mingw32/usr/lib
popenv
popenv

# task [054/067] /i686-mingw32/toolchain/copy_libs
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/symbian/obj/tools-i686-pc-linux-gnu-2007q3-52-arm-none-symbianelf-i686-mingw32/bin
copy_dir /scratch/paul/symbian/obj/tools-i686-pc-linux-gnu-2007q3-52-arm-none-symbianelf-i686-mingw32/share/doc/arm-2007q3-52-arm-none-symbianelf/html /scratch/paul/symbian/install/host-i686-mingw32/share/doc/arm-2007q3-52-arm-none-symbianelf/html
copy_dir /scratch/paul/symbian/obj/tools-i686-pc-linux-gnu-2007q3-52-arm-none-symbianelf-i686-mingw32/share/doc/arm-2007q3-52-arm-none-symbianelf/pdf /scratch/paul/symbian/install/host-i686-mingw32/share/doc/arm-2007q3-52-arm-none-symbianelf/pdf
cp /scratch/paul/symbian/obj/tools-i686-pc-linux-gnu-2007q3-52-arm-none-symbianelf-i686-mingw32/share/doc/arm-2007q3-52-arm-none-symbianelf/LICENSE.txt /scratch/paul/symbian/install/host-i686-mingw32/share/doc/arm-2007q3-52-arm-none-symbianelf
popenv

# task [055/067] /i686-mingw32/toolchain/gcc_final/configure
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/symbian/obj/tools-i686-pc-linux-gnu-2007q3-52-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushenvvar AR_FOR_TARGET arm-none-symbianelf-ar
pushenvvar NM_FOR_TARGET arm-none-symbianelf-nm
pushenvvar OBJDUMP_FOR_TARET arm-none-symbianelf-objdump
pushenvvar STRIP_FOR_TARGET arm-none-symbianelf-strip
pushenvvar CC_FOR_TARGET arm-none-symbianelf-gcc
pushenvvar GCC_FOR_TARGET arm-none-symbianelf-gcc
pushenvvar CXX_FOR_TARGET arm-none-symbianelf-g++
rm -rf /scratch/paul/symbian/obj/gcc-2007q3-52-arm-none-symbianelf-i686-mingw32
mkdir -p /scratch/paul/symbian/obj/gcc-2007q3-52-arm-none-symbianelf-i686-mingw32
pushd /scratch/paul/symbian/obj/gcc-2007q3-52-arm-none-symbianelf-i686-mingw32
/scratch/paul/symbian/src/gcc-4.2/configure --build=i686-pc-linux-gnu --host=i686-mingw32 --target=arm-none-symbianelf --enable-threads --disable-libmudflap --disable-libssp --disable-libgomp --disable-libstdcxx-pch --with-gnu-as --with-gnu-ld --enable-languages=c,c++ --enable-shared '--with-pkgversion=CodeSourcery Sourcery G++ Lite 2007q3-52' --with-bugurl=https://support.codesourcery.com/GNUToolchain/ --disable-nls --prefix=/opt/codesourcery --with-libiconv-prefix=/scratch/paul/symbian/obj/host-libs-2007q3-52-arm-none-symbianelf-i686-mingw32/usr --enable-poison-system-directories --with-build-time-tools=/scratch/paul/symbian/obj/tools-i686-pc-linux-gnu-2007q3-52-arm-none-symbianelf-i686-mingw32/arm-none-symbianelf/bin --with-build-time-tools=/scratch/paul/symbian/obj/tools-i686-pc-linux-gnu-2007q3-52-arm-none-symbianelf-i686-mingw32/arm-none-symbianelf/bin
popd
popenv
popenv

# task [056/067] /i686-mingw32/toolchain/gcc_final/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/symbian/obj/tools-i686-pc-linux-gnu-2007q3-52-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushenvvar AR_FOR_TARGET arm-none-symbianelf-ar
pushenvvar NM_FOR_TARGET arm-none-symbianelf-nm
pushenvvar OBJDUMP_FOR_TARET arm-none-symbianelf-objdump
pushenvvar STRIP_FOR_TARGET arm-none-symbianelf-strip
pushenvvar CC_FOR_TARGET arm-none-symbianelf-gcc
pushenvvar GCC_FOR_TARGET arm-none-symbianelf-gcc
pushenvvar CXX_FOR_TARGET arm-none-symbianelf-g++
pushd /scratch/paul/symbian/obj/gcc-2007q3-52-arm-none-symbianelf-i686-mingw32
make -j4 all-gcc
popd
popenv
popenv

# task [057/067] /i686-mingw32/toolchain/gcc_final/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/symbian/obj/tools-i686-pc-linux-gnu-2007q3-52-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushenvvar AR_FOR_TARGET arm-none-symbianelf-ar
pushenvvar NM_FOR_TARGET arm-none-symbianelf-nm
pushenvvar OBJDUMP_FOR_TARET arm-none-symbianelf-objdump
pushenvvar STRIP_FOR_TARGET arm-none-symbianelf-strip
pushenvvar CC_FOR_TARGET arm-none-symbianelf-gcc
pushenvvar GCC_FOR_TARGET arm-none-symbianelf-gcc
pushenvvar CXX_FOR_TARGET arm-none-symbianelf-g++
pushd /scratch/paul/symbian/obj/gcc-2007q3-52-arm-none-symbianelf-i686-mingw32
make prefix=/scratch/paul/symbian/install/host-i686-mingw32 exec_prefix=/scratch/paul/symbian/install/host-i686-mingw32 libdir=/scratch/paul/symbian/install/host-i686-mingw32/lib htmldir=/scratch/paul/symbian/install/host-i686-mingw32/share/doc/arm-2007q3-52-arm-none-symbianelf/html pdfdir=/scratch/paul/symbian/install/host-i686-mingw32/share/doc/arm-2007q3-52-arm-none-symbianelf/pdf infodir=/scratch/paul/symbian/install/host-i686-mingw32/share/doc/arm-2007q3-52-arm-none-symbianelf/info mandir=/scratch/paul/symbian/install/host-i686-mingw32/share/doc/arm-2007q3-52-arm-none-symbianelf/man install-gcc
popd
popenv
popenv

# task [058/067] /i686-mingw32/toolchain/gcc_final/postinstall
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/symbian/obj/tools-i686-pc-linux-gnu-2007q3-52-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushenvvar AR_FOR_TARGET arm-none-symbianelf-ar
pushenvvar NM_FOR_TARGET arm-none-symbianelf-nm
pushenvvar OBJDUMP_FOR_TARET arm-none-symbianelf-objdump
pushenvvar STRIP_FOR_TARGET arm-none-symbianelf-strip
pushenvvar CC_FOR_TARGET arm-none-symbianelf-gcc
pushenvvar GCC_FOR_TARGET arm-none-symbianelf-gcc
pushenvvar CXX_FOR_TARGET arm-none-symbianelf-g++
pushd /scratch/paul/symbian/install/host-i686-mingw32
rm -f lib/libiberty.a
rm -f bin/arm-none-symbianelf-gccbug
rm -f 'bin/gccbug*'
rm -f lib/charset.alias
popd
copy_dir /scratch/paul/symbian/obj/tools-i686-pc-linux-gnu-2007q3-52-arm-none-symbianelf-i686-mingw32/lib/gcc/arm-none-symbianelf /scratch/paul/symbian/install/host-i686-mingw32/lib/gcc/arm-none-symbianelf
copy_dir /scratch/paul/symbian/obj/tools-i686-pc-linux-gnu-2007q3-52-arm-none-symbianelf-i686-mingw32/arm-none-symbianelf/lib /scratch/paul/symbian/install/host-i686-mingw32/arm-none-symbianelf/lib
copy_dir /scratch/paul/symbian/obj/tools-i686-pc-linux-gnu-2007q3-52-arm-none-symbianelf-i686-mingw32/arm-none-symbianelf/include/c++ /scratch/paul/symbian/install/host-i686-mingw32/arm-none-symbianelf/include/c++
popenv
popenv

# task [059/067] /i686-mingw32/pretidy_installation
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/symbian/obj/tools-i686-pc-linux-gnu-2007q3-52-arm-none-symbianelf-i686-mingw32/bin
pushd /scratch/paul/symbian/install/host-i686-mingw32
rm -f lib/libiberty.a
rm -f 'bin/*gccbug'
rm -f 'bin/gccbug*'
rm -f lib/charset.alias
popd
popenv

# task [060/067] /i686-mingw32/remove_libtool_archives
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/symbian/obj/tools-i686-pc-linux-gnu-2007q3-52-arm-none-symbianelf-i686-mingw32/bin
find /scratch/paul/symbian/install/host-i686-mingw32 -name '*.la' -exec rm '{}' ';'
popenv

# task [061/067] /i686-mingw32/remove_fixed_headers
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/symbian/obj/tools-i686-pc-linux-gnu-2007q3-52-arm-none-symbianelf-i686-mingw32/bin
pushd /scratch/paul/symbian/install/host-i686-mingw32/lib/gcc/arm-none-symbianelf/4.2.1/include-fixed
popd
popenv

# task [062/067] /i686-mingw32/strip_host_objects
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/symbian/obj/tools-i686-pc-linux-gnu-2007q3-52-arm-none-symbianelf-i686-mingw32/bin
i686-mingw32-strip /scratch/paul/symbian/install/host-i686-mingw32/bin/arm-none-symbianelf-addr2line.exe
i686-mingw32-strip /scratch/paul/symbian/install/host-i686-mingw32/bin/arm-none-symbianelf-ar.exe
i686-mingw32-strip /scratch/paul/symbian/install/host-i686-mingw32/bin/arm-none-symbianelf-as.exe
i686-mingw32-strip /scratch/paul/symbian/install/host-i686-mingw32/bin/arm-none-symbianelf-c++.exe
i686-mingw32-strip /scratch/paul/symbian/install/host-i686-mingw32/bin/arm-none-symbianelf-c++filt.exe
i686-mingw32-strip /scratch/paul/symbian/install/host-i686-mingw32/bin/arm-none-symbianelf-cpp.exe
i686-mingw32-strip /scratch/paul/symbian/install/host-i686-mingw32/bin/arm-none-symbianelf-g++.exe
i686-mingw32-strip /scratch/paul/symbian/install/host-i686-mingw32/bin/arm-none-symbianelf-gcc-4.2.1.exe
i686-mingw32-strip /scratch/paul/symbian/install/host-i686-mingw32/bin/arm-none-symbianelf-gcc.exe
i686-mingw32-strip /scratch/paul/symbian/install/host-i686-mingw32/bin/arm-none-symbianelf-gcov.exe
i686-mingw32-strip /scratch/paul/symbian/install/host-i686-mingw32/bin/arm-none-symbianelf-gprof.exe
i686-mingw32-strip /scratch/paul/symbian/install/host-i686-mingw32/bin/arm-none-symbianelf-ld.exe
i686-mingw32-strip /scratch/paul/symbian/install/host-i686-mingw32/bin/arm-none-symbianelf-nm.exe
i686-mingw32-strip /scratch/paul/symbian/install/host-i686-mingw32/bin/arm-none-symbianelf-objcopy.exe
i686-mingw32-strip /scratch/paul/symbian/install/host-i686-mingw32/bin/arm-none-symbianelf-objdump.exe
i686-mingw32-strip /scratch/paul/symbian/install/host-i686-mingw32/bin/arm-none-symbianelf-ranlib.exe
i686-mingw32-strip /scratch/paul/symbian/install/host-i686-mingw32/bin/arm-none-symbianelf-readelf.exe
i686-mingw32-strip /scratch/paul/symbian/install/host-i686-mingw32/bin/arm-none-symbianelf-size.exe
i686-mingw32-strip /scratch/paul/symbian/install/host-i686-mingw32/bin/arm-none-symbianelf-strings.exe
i686-mingw32-strip /scratch/paul/symbian/install/host-i686-mingw32/bin/arm-none-symbianelf-strip.exe
i686-mingw32-strip /scratch/paul/symbian/install/host-i686-mingw32/bin/cs-make.exe
i686-mingw32-strip /scratch/paul/symbian/install/host-i686-mingw32/bin/cs-rm.exe
i686-mingw32-strip /scratch/paul/symbian/install/host-i686-mingw32/arm-none-symbianelf/bin/ar.exe
i686-mingw32-strip /scratch/paul/symbian/install/host-i686-mingw32/arm-none-symbianelf/bin/as.exe
i686-mingw32-strip /scratch/paul/symbian/install/host-i686-mingw32/arm-none-symbianelf/bin/c++.exe
i686-mingw32-strip /scratch/paul/symbian/install/host-i686-mingw32/arm-none-symbianelf/bin/g++.exe
i686-mingw32-strip /scratch/paul/symbian/install/host-i686-mingw32/arm-none-symbianelf/bin/gcc.exe
i686-mingw32-strip /scratch/paul/symbian/install/host-i686-mingw32/arm-none-symbianelf/bin/ld.exe
i686-mingw32-strip /scratch/paul/symbian/install/host-i686-mingw32/arm-none-symbianelf/bin/nm.exe
i686-mingw32-strip /scratch/paul/symbian/install/host-i686-mingw32/arm-none-symbianelf/bin/objcopy.exe
i686-mingw32-strip /scratch/paul/symbian/install/host-i686-mingw32/arm-none-symbianelf/bin/objdump.exe
i686-mingw32-strip /scratch/paul/symbian/install/host-i686-mingw32/arm-none-symbianelf/bin/ranlib.exe
i686-mingw32-strip /scratch/paul/symbian/install/host-i686-mingw32/arm-none-symbianelf/bin/strip.exe
i686-mingw32-strip /scratch/paul/symbian/install/host-i686-mingw32/libexec/gcc/arm-none-symbianelf/4.2.1/cc1.exe
i686-mingw32-strip /scratch/paul/symbian/install/host-i686-mingw32/libexec/gcc/arm-none-symbianelf/4.2.1/collect2.exe
i686-mingw32-strip /scratch/paul/symbian/install/host-i686-mingw32/libexec/gcc/arm-none-symbianelf/4.2.1/install-tools/fixincl.exe
i686-mingw32-strip /scratch/paul/symbian/install/host-i686-mingw32/libexec/gcc/arm-none-symbianelf/4.2.1/cc1plus.exe
popenv

# task [063/067] /i686-mingw32/package_tbz2
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/symbian/obj/tools-i686-pc-linux-gnu-2007q3-52-arm-none-symbianelf-i686-mingw32/bin
rm -f /scratch/paul/symbian/pkg/arm-2007q3-52-arm-none-symbianelf-i686-mingw32.tar.bz2
pushd /scratch/paul/symbian/install/host-i686-mingw32
popd
pushd /scratch/paul/symbian/obj
rm -f arm-2007q3
ln -s /scratch/paul/symbian/install/host-i686-mingw32 arm-2007q3
tar cjf /scratch/paul/symbian/pkg/arm-2007q3-52-arm-none-symbianelf-i686-mingw32.tar.bz2 --owner=0 --group=0 --exclude=host-i686-pc-linux-gnu --exclude=host-i686-mingw32 arm-2007q3/arm-none-symbianelf arm-2007q3/bin arm-2007q3/include arm-2007q3/lib arm-2007q3/libexec arm-2007q3/share
rm -f arm-2007q3
popd
popenv

# task [064/067] /i686-mingw32/package_installanywhere
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
prepend_path PATH /scratch/paul/symbian/obj/tools-i686-pc-linux-gnu-2007q3-52-arm-none-symbianelf-i686-mingw32/bin
/scratch/paul/symbian/src/scripts-trunk/gnu-installanywhere -i /scratch/paul/symbian/install/host-i686-mingw32 -l /scratch/paul/symbian/logs -o /scratch/paul/symbian/obj -p /scratch/paul/symbian/pkg -s /scratch/paul/symbian/src -T /scratch/paul/symbian/testlogs -h i686-mingw32 -f /scratch/paul/symbian/obj/getting_started-2007q3-52-arm-none-symbianelf/license.html 4.2-arm-none-symbianelf-lite
popenv

# task [065/067] /fini/build_summary
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
cat > /scratch/paul/symbian/obj/gnu-2007q3-52-arm-none-symbianelf.txt <<'EOF0'
Version Information
===================

Version:           2007q3-52
Host(s):           i686-pc-linux-gnu i686-mingw32
Target:            arm-none-symbianelf

Build Information
=================

Build date:             20070928
Build machine:          daisy.codesourcery.com
Build operating system: 4.0
Build uname:            Linux daisy.codesourcery.com 2.6.20-16-generic #2 SMP Thu Jun 7 19:00:28 UTC 2007 x86_64 unknown unknown GNU/Linux
Build user:             paul

EOF0
popenv

# task [066/067] /fini/backup_package
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
mkdir -p /scratch/paul/symbian/obj/pkg-2007q3-52-arm-none-symbianelf/arm-2007q3-52-arm-none-symbianelf.backup
pushd /scratch/paul/symbian/obj/pkg-2007q3-52-arm-none-symbianelf
tar cjf /scratch/paul/symbian/pkg/arm-2007q3-52-arm-none-symbianelf.backup.tar.bz2 --owner=0 --group=0 arm-2007q3-52-arm-none-symbianelf.backup
popd
popenv

# task [067/067] /fini/source_package
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
mkdir -p /scratch/paul/symbian/obj/pkg-2007q3-52-arm-none-symbianelf/arm-2007q3-52-arm-none-symbianelf
cp /scratch/paul/symbian/obj/gnu-2007q3-52-arm-none-symbianelf.txt /scratch/paul/symbian/obj/pkg-2007q3-52-arm-none-symbianelf/arm-2007q3-52-arm-none-symbianelf
cp /scratch/paul/symbian/logs/arm-2007q3-52-arm-none-symbianelf.sh /scratch/paul/symbian/obj/pkg-2007q3-52-arm-none-symbianelf/arm-2007q3-52-arm-none-symbianelf
pushd /scratch/paul/symbian/obj/pkg-2007q3-52-arm-none-symbianelf
tar cjf /scratch/paul/symbian/pkg/arm-2007q3-52-arm-none-symbianelf.src.tar.bz2 --owner=0 --group=0 arm-2007q3-52-arm-none-symbianelf
popd
/scratch/paul/symbian/src/scripts-trunk/gnu-test -i /scratch/paul/symbian/install -l /scratch/paul/symbian/logs -o /scratch/paul/symbian/obj -p /scratch/paul/symbian/pkg -s /scratch/paul/symbian/src -T /scratch/paul/symbian/testlogs -T /scratch/paul/symbian/obj/testlogs-2007q3-52-arm-none-symbianelf 4.2-arm-none-symbianelf-lite
copy_dir /scratch/paul/symbian/obj/testlogs-2007q3-52-arm-none-symbianelf /scratch/paul/symbian/testlogs
/scratch/paul/symbian/src/scripts-trunk/gnu-test-package -i /scratch/paul/symbian/install -l /scratch/paul/symbian/logs -o /scratch/paul/symbian/obj -p /scratch/paul/symbian/pkg -s /scratch/paul/symbian/src -T /scratch/paul/symbian/testlogs -T /scratch/paul/symbian/obj/testlogs-2007q3-52-arm-none-symbianelf 4.2-arm-none-symbianelf-lite
